#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <locale.h>

#define MAX_TEXT_LEN 500000
#define MAX_WORDS 150000

int readText(char *buf, int len)
/* reads stuff from stdin into buf until EOF or until len-1 chars have 
been read, returns number of chars read.  The stuff in dest is 
0-terminated */
{
  char *cp=buf;
  int c;

  while (((c=fgetc(stdin))!=EOF) && cp-buf<len-1) {
    *cp++ = c;
  }
  *cp = 0;
  return cp-buf;
}


char *zeroOutNonAlphas(char *cp)
/* writes zeroes into the string pointed to by *cp until it meets either
an alphabetic character or a zero, returns a pointer to the first 
alphabetic character found */
{
  while (!isalpha(*cp) && *cp) {
    *cp++ = 0;
  }
  return cp;
}


char *skipAlphas(char *cp)
/* returns a pointer to the next non-alphabetic character after cp */
{
  while (isalpha(*cp)) {
    cp++;
  }
  return cp;
}


void parseIntoWords(char *buf, char **words, int wordsLen)
/* fills words with pointers to all words (sequences of alpha) in the
c-string buf.  buf is modified such that all non-alpha chars become 
zeroes.  If there are more than wordsLen words in buf, the last
word contains the entire rest of buf. */
{
  char *cp=buf;
  char **word=words;

  while (1) {
    cp = zeroOutNonAlphas(cp);
    if (!*cp) {
      break;
    }
    *word++ = cp;
    if (word-words>=wordsLen-1) {
      break;
    }
    cp = skipAlphas(cp);
  }
  *word = NULL;
}



void doSomething(char **words)
{
  while (*words) {
    printf("%s\n", *words++);
  }
  (*words)++;
}




int main(void)
{
  char buf[MAX_TEXT_LEN];
  char *words[MAX_WORDS];

  setlocale(LC_ALL, "");
  readText(buf, MAX_TEXT_LEN);
  parseIntoWords(buf, words, MAX_WORDS);
  doSomething(words);
  return 0;
}


